@@ -668,6 +668,10 @@ main = hspec $ do
         res1 <- yieldMany strs $$ linesUnboundedC =$ sinkList
         res2 <- yieldMany strs $$ peekForever (lineC $ foldC >>= yield) =$ sinkList
         res2 `shouldBe` res1
+    prop "peekForeverE" $ \(strs :: [String]) -> do
+        res1 <- yieldMany strs $$ linesUnboundedC =$ sinkList
+        res2 <- yieldMany strs $$ peekForeverE (lineC $ foldC >>= yield) =$ sinkList
+        res2 `shouldBe` res1
     StreamSpec.spec
 
 evenInt :: Int -> Bool
